View source: R/expected_coverage.R
| expected_coverage | R Documentation |
Find the expected number of strata covered by ordinary Poisson sampling without stratification. As sequential and ordinary Poisson sampling have the same sample size on average, this gives an approximation for the coverage under sequential Poisson sampling.
This function can also be used to calculate, e.g., the expected number of enterprises covered within a stratum when sampling business establishments.
expected_coverage(x, n, strata, alpha = 0.001, cutoff = Inf)
x |
|
n |
|
strata |
|
alpha |
|
cutoff |
|
The expected number of strata covered by the sample design.
prop_allocation() for generating proportional-to-size allocations.
# Make a population with units of different size
x <- c(rep(1:9, each = 3), 100, 100, 100)
# ... and 10 strata
s <- rep(letters[1:10], each = 3)
# Should get about 7 to 8 strata in a sample on average
expected_coverage(x, 15, s)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.